<?php
/**
 * Created by Robert Burleson
 * Date: 10/11/2024
 * Class: PHP CSD275
 * This is the loan (mortgage) calculator.... that takes in your initial value the interest rate and the number of years expected to pay it off.
 * It will then calculate the monthly payment and the total interested payed over the period of payment
 * 
 * Stylesheet taken from Test Example Code
 */
?>

<html>
<head>
    <style>
        body {
            font-family: Arial, Helvetica, sans-serif;
            background-color: buttonface;
        }
        main {
            width: 470px;
            margin: 100px auto;
            padding: 1em;
            background: lightcyan;
            border: 2px solid navy;
        }
        h1 {
            margin-top: 30px;
            color: navy;
            text-align: center;
        }
        label {
            width: 15em;
            float: left;
            padding-right: 1em;
            padding-bottom: .5em;
        }
        #data input {
            float: left;
            width: 15em;
            margin-bottom: .5em;
        }
        #buttons input {
            margin: auto;
            margin-bottom: .5em;
        }
        br {
            clear: left;
        }
        .error {
            color: red;
            font-weight: bold;
        }
    </style>
</head>
<body>
<?php 
// Changed position and code to get rid of warning and check for values. Moved up here to be used in if statement check.
// Loan amount
$loanAmount = isset($_REQUEST['loan_amount']) ? $_REQUEST['loan_amount'] : null;

// Monthly rate
$annualRate = isset($_REQUEST['annual_rate']) ? $_REQUEST['annual_rate'] : null;

// Months in the loan period
$periodInYears = isset($_REQUEST['years']) ? $_REQUEST['years'] : null;

// Display form if data has not yet been entered and submitted else it will only show results of calculations
if (!$loanAmount || !$annualRate || !$periodInYears) {
?>
    <main>
    <h1 align="center">Loan Calculator</h1>

    <div>
        <form method="get">
            <table align="center">
                <tr>
                    <td> Loan Amount</td>
                    <td><input name="loan_amount" type="text" value="5000"/></td>
                </tr>
                <tr>
                    <td> Interest Rate (annual %)</td>
                    <td><input name="annual_rate" type="text" value="12"/></td>
                </tr>
                <tr>
                    <td> Period in years</td>
                    <td><input name="years" type="text" value="3"></td>
                </tr>
                <tr>
                    <td><input type="submit"></td>
                </tr>

            </table>
        </form>
    </div>
<?php
} 
else 
{
    // Convert annual rate to monthly rate and decimal
    $monthRate = $annualRate / 12 / 100;

    // Total number of months
    $totalMonths = $periodInYears * 12;

    // Monthly Payment Calc
    $monthlyPayment = ($loanAmount * $monthRate) / (1 - pow(1 + $monthRate, -$totalMonths));

    // Difference between total money payed and innital sum loaned
    $totalInterest = ($monthlyPayment * $totalMonths) - $loanAmount;

    // Display the results of the input and the calculations
    echo "<main>";
        echo "<h1 align='center'>Loan Calculator</h1>";
        echo "<table align='center'>";
            echo "<tr><td>Loan Amount:</td><td> $" . number_format($loanAmount, 2) . "</td></tr>";
            echo "<tr><td>Annual Rate:</td><td> " . number_format($annualRate, 2) . "%</td></tr>";
            echo "<tr><td>Years in the loan period:</td><td> " . $periodInYears . "</td></tr>";
            echo "<tr><td>Monthly payment is:</td><td> $" . number_format($monthlyPayment, 2) . "</td></tr>";
            echo "<tr><td>Total Interest is:</td><td> $" . number_format($totalInterest, 2) . "</td></tr>";
        echo "</table>";
}
?>
    </main>
</body>
</html>
